import QtQuick 2.4
import QtQuick.Controls 1.3
import QtQuick.Layouts 1.1
import QtQuick.Dialogs 1.2
import Qt.labs.folderlistmodel 2.1
// Internal Qml classes
import QmlEnvVars 0.1

Item {
    id: page
    property int requiredWidth: 300
    anchors.fill: parent
    anchors.margins: 3

    ShellEnv   { id: environment }
    FolderListModel {       // Build ListModel with directory's files list
        id: fileModel
        showDirs: true
        showDirsFirst: true
        showDotAndDotDot: true
        sortField: FolderListModel.Name
        folder: "file://"+dirname.text
    }
    FileDialog {
        id: fileDialog
        title: "Choose directory"
        folder: "file://"+dirname.text
        modality: Qt.WindowModal
        selectFolder: true
        onAccepted: {
            var str = fileDialog.fileUrl.toString();
            str = str.replace(/file:\/\//,'');      // Delete protocol
            dirname.text = str;
        }
        onRejected: state = "";
    }
    ColumnLayout {
        anchors.fill: parent
        anchors.margins: 5
        anchors.horizontalCenter: parent.horizontalCenter
        spacing: 5
        RowLayout {
            anchors.fill: parent
            anchors.topMargin: 3
            Text {
                height: 20
                text: "Directory"
                font.bold: true
            }
            Item { Layout.fillWidth: true }
            Button {
                Layout.preferredHeight: 20
                text: "Browse"
                onClicked: {
                    fileDialog.folder = "file://"+dirname.text;
                    fileDialog.open();
                }
            }
        }
        TextField {
            id: dirname
            Layout.fillWidth: true
            height: 25
            text: environment.getVar("HOME")
            readOnly: true
        }
        ScrollView {
            Layout.fillWidth: true
            Layout.fillHeight: true
            frameVisible: true
            ListView {
                id: mylist
                anchors.fill: parent
                anchors.margins: 3
                clip: true
                spacing: 5
                model: fileModel
                delegate: Item {
                    width: parent.width
                    height: 16
                    Text {
                        lineHeightMode: Text.FixedHeight
                        lineHeight: 14;
                        text: (fileIsDir) ? fileName+"/" : fileName
                    }
                }
                highlightFollowsCurrentItem: true
                highlightMoveDuration: 0
                highlight: Component {
                    Rectangle {
                        color: "lightsteelblue"
                        y: (mylist.currentIndex != -1) ? mylist.currentItem.y : 0
                    }
                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        parent.focus = true;
                        var idx = mylist.indexAt(mouseX,mouseY+mylist.contentY);
                        if (idx === -1) return;
                        mylist.currentIndex = idx;
                        var args = fileModel.get(mylist.currentIndex,"fileName");
                        if (fileModel.get(mylist.currentIndex,"fileIsDir")) {
                            args = Qt.resolvedUrl("file://"+dirname.text+"/"+args); // Add protocol for Qt.resolveUrl()
                            args = args.replace(/file:\/\//,'');                    // Delete protocol not needed
                            if (args === "") args="/";
                            if (args.charAt(0) !== "/") args = "/"+args;
                            dirname.text = args;
                            sx_scriptargs = "\""+args+"\"";
                            sx_execAction.trigger();
                        }
                    }
                }
                onCurrentIndexChanged: {
                    if (!fileModel.get(mylist.currentIndex,"fileIsDir")) {
                        sx_scriptargs = "\""+dirname.text+"/"+fileModel.get(currentIndex,"fileName")+"\"";
                        sx_execAction.trigger();
                    }
                }
            }
        }
    }
}
