import QtQuick 2.4
import QtQuick.Controls 1.3
import QtQuick.Layouts 1.1
import QtQuick.Dialogs 1.2

Item {
    id: page
    property int requiredWidth: 230
    property bool ready: false
    anchors.fill: parent
    anchors.margins: 3
    clip: true

    // Form argument line, trigerred on value changed
    function updateParams() {
        if (!ready) return;
        var str = "";
        str += dirname.text;
        if (executable.checked) str += " -executable";
        if (pattern.text !== "") {
            if (regex.checked) {
                if (icase.checked) str += " -iregex ";
                else               str += " -regex ";
            } else {
                if (icase.checked) str += " -iname ";
                else               str += " -name ";
            }
            str += "\""+pattern.text+"\"";
        }
        if (mtime.checked) str += " -mtime -"+age.text;
        if (mmin.checked)  str += " -mmin -"+agemin.text;
        sx_scriptargs = str;       // Set global variable sx_scriptargs
    }

    ExclusiveGroup { id: timegroup }    // Radio buttons group
    Flickable {
        anchors.fill: parent
        contentHeight: maincolumn.height
        ColumnLayout {
            id: maincolumn
            anchors.horizontalCenter: parent.horizontalCenter
            spacing: 5
            RowLayout {
                anchors.fill: parent
                anchors.topMargin: 3
                Text {
                    text: "Directory"
                    font.bold: true
                }
                Item { Layout.fillWidth: true }
                Button {
                    text: "Browse"
                    onClicked: {
                        fileDialog.folder = dirname.text;
                        fileDialog.open();
                    }
                }
            }
            TextField {
                id: dirname
                Layout.fillWidth: true
                text: "~"
                onTextChanged: updateParams();
            }
            Text {
                Layout.alignment: Qt.AlignHCenter
                text: "Pattern"
                font.bold: true
            }
            TextField {
                id: pattern
                Layout.fillWidth: true
                text: "*.txt"
                onTextChanged: updateParams();
            }
            CheckBox {
                id: icase
                text: "Case insensitive"
                onCheckedChanged: updateParams();
            }
            CheckBox {
                id: regex
                text: "Regular expression"
                onCheckedChanged: updateParams();
            }
            CheckBox {
                id: executable
                text: "Executable"
                onCheckedChanged: updateParams();
            }
            Text {
                Layout.alignment: Qt.AlignHCenter
                text: "Date"
                font.bold: true
            }
            RadioButton {
                id: notime
                text: "Anytime"
                exclusiveGroup: timegroup
                checked: true
                onCheckedChanged: updateParams();
            }
            Row {
                spacing: 5
                RadioButton {
                    id: mtime
                    text: "Modified since"
                    exclusiveGroup: timegroup
                    onCheckedChanged: updateParams();
                }
                TextField {
                    id: age
                    Layout.fillWidth: true
                    width: 30
                    text: "1"
                    validator: IntValidator { bottom: 1; top: 20; }
                    enabled: mtime.checked
                    onTextChanged: updateParams();
                }
                Text {
                    opacity: mtime.checked ? 1.0 : 0.5;
                    text: "days"
                }
            }
            Row {
                spacing: 5
                RadioButton {
                    id: mmin
                    text: "Modified since"
                    exclusiveGroup: timegroup
                    onCheckedChanged: updateParams();
                }
                TextField {
                    id: agemin
                    Layout.fillWidth: true
                    width: 40
                    text: "60"
                    validator: IntValidator { bottom: 1; top: 3000; }
                    enabled: mmin.checked
                    onTextChanged: updateParams();
                }
                Text {
                    opacity: mmin.checked ? 1.0 : 0.5;
                    text: "minutes"
                }
            }
        }
    }

    FileDialog {
        id: fileDialog
        title: "Choose directory"
        nameFilters: [ "Qml file (Scripts.qml)" ]
        modality: Qt.WindowModal
        selectFolder: true
        onAccepted: {
            var str = fileDialog.fileUrl.toString();
            str = str.replace(/file:\/\//,'');                     // Delete protocol
            dirname.text = str;
        }
        onRejected: state = "";
    }

    // Set initial parameters when completed
    Component.onCompleted: { ready = true; updateParams(); }
}
