import QtQuick 2.4
import QtQuick.Controls 1.3
import QtQuick.Layouts 1.1
import QtQuick.Dialogs 1.2

Item {
    id: page
    property int requiredWidth: 170
    property bool ready: false
    anchors.fill: parent
    anchors.margins: 3
    clip: true

    // Form argument line, trigerred on value changed
    function updateParams() {
        if (!ready) return;
        if (filefilter.text === "") filefilter.text = "*";
        var str = "";
        if (icase.checked)      str += "-i ";
        if (recursive.checked)  str += "-r ";
        if (linenumber.checked) str += "-n ";
        if (regex.checked)      str += "-e ";
        if (nobinary.checked)   str += "-I ";
        str += "\""+pattern.text+"\" ";
        str += dirname.text+"/"+filefilter.text;
        sx_scriptargs = str;       // Set global variable sx_scriptargs
    }

    Flickable {
        anchors.fill: parent
        contentHeight: maincolumn.height
        ColumnLayout {
            id: maincolumn
            anchors.horizontalCenter: parent.horizontalCenter
            spacing: 5
            RowLayout {
                anchors.fill: parent
                anchors.topMargin: 3
                Text {
                    text: "Directory"
                    font.bold: true
                }
                Item { Layout.fillWidth: true }
                Button {
                    text: "Browse"
                    onClicked: {
                        fileDialog.folder = dirname.text;
                        fileDialog.open();
                    }
                }
            }
            TextField {
                id: dirname
                Layout.fillWidth: true
                text: "."
                onTextChanged: updateParams();
            }
            Text {
                Layout.alignment: Qt.AlignHCenter
                text: "File filter"
                font.bold: true
            }
            TextField {
                id: filefilter
                Layout.fillWidth: true
                text: "*"
                onTextChanged: updateParams();
            }
            Text {
                Layout.alignment: Qt.AlignHCenter
                text: "Pattern"
                font.bold: true
            }
            TextField {
                id: pattern
                Layout.fillWidth: true
                text: "QtQuick"
                onTextChanged: updateParams();
            }
            CheckBox {
                id: icase
                text: "Case insensitive"
                onCheckedChanged: updateParams();
            }
            CheckBox {
                id: recursive
                text: "Recursive"
                onCheckedChanged: updateParams();
            }
            CheckBox {
                id: nobinary
                text: "Exclude binaries"
                onCheckedChanged: updateParams();
            }
            CheckBox {
                id: linenumber
                text: "Print line number"
                onCheckedChanged: updateParams();
            }
            CheckBox {
                id: regex
                text: "Regular expression"
                onCheckedChanged: updateParams();
            }
        }
    }

    FileDialog {
        id: fileDialog
        title: "Choose directory"
        nameFilters: [ "Qml file (Scripts.qml)" ]
        modality: Qt.WindowModal
        selectFolder: true
        onAccepted: {
            var str = fileDialog.fileUrl.toString();
            str = str.replace(/file:\/\//,'');        // Delete protocol
            dirname.text = str;
        }
        onRejected: state = "";
    }

    // Set initial parameters when completed
    Component.onCompleted: { ready = true; updateParams(); }
}
