import QtQuick 2.4
import QtQuick.Controls 1.3
import QtQuick.Layouts 1.1
import QtQuick.Dialogs 1.2

Item {
    id: page
    property int requiredWidth: 200
    property bool ready: false
    anchors.fill: parent
    anchors.margins: 3

    // Form argument line, trigerred on value changed
    function updateParams() {
        if (!ready) return;
        var str = "";
        if (longlist.checked)  str += "-l ";
        if (recursive.checked) str += "-R ";
        if (hidden.checked)    str += "-a ";
        if (reverse.checked)   str += "-r ";
        str += dirname.text;
        sx_scriptargs = str;       // Set global variable sx_scriptargs
    }

    ColumnLayout {
        width: parent.width-10
        anchors.horizontalCenter: parent.horizontalCenter
        spacing: 5
        RowLayout {
            anchors.fill: parent
            anchors.topMargin: 3
            Text {
                height: 20
                text: "Directory"
                font.bold: true
            }
            Item { Layout.fillWidth: true }
            Button {
                Layout.preferredHeight: 20
                text: "Browse"
                onClicked: {
                    fileDialog.folder = dirname.text;
                    fileDialog.open();
                }
            }
        }
        TextField {
            id: dirname
            Layout.fillWidth: true
            height: 25
            text: "~"
            onTextChanged: updateParams();
        }
        CheckBox {
            id: longlist
            height: 25
            text: "Long list"
            onCheckedChanged: updateParams();
        }
        CheckBox {
            id: recursive
            height: 25
            text: "Recursive"
            onCheckedChanged: updateParams();
        }
        CheckBox {
            id: hidden
            height: 25
            text: "Hidden files"
            onCheckedChanged: updateParams();
        }
        CheckBox {
            id: reverse
            height: 25
            text: "Reverse sort"
            onCheckedChanged: updateParams();
        }
    }

    FileDialog {
        id: fileDialog
        title: "Choose directory"
        nameFilters: [ "Qml file (Scripts.qml)" ]
        modality: Qt.WindowModal
        selectFolder: true
        onAccepted: {
            var str = fileDialog.fileUrl.toString();
            str = str.replace(/file:\/\//,'');      // Delete protocol
            dirname.text = str;
        }
        onRejected: state = "";
    }

    // Set initial parameters when completed
    Component.onCompleted: { ready = true; updateParams(); }
}
