import QtQuick 2.4
import QtQuick.Controls 1.3
import QtQuick.Layouts 1.1
import QmlEnvVars 0.1
import QmlFile 0.1

Item {
    id: page
    property int requiredWidth: 180
    property bool ready: false
    property var hostslist: [ "github.com", "duckduckgo.com", "qt.io", "fsf.org", "wikipedia.com" ]
    property string datafile: environment.getVar("HOME")+"/sx_hosts.json"
    // datafile is in $HOME because directory /usr/share/scriptomatix/examples is read only
    // You should write this file in scriptomatix's current directory : sx_scriptpath+"/hosts.json"
    anchors.fill: parent
    anchors.margins: 3

    // Format argument line, trigerred on value changed
    function updateParams(idx,obj) {
        if (!ready) return;
        var str = "";
        if ((obj) && (obj.checked)) {
            str += hostslist[idx];
            sx_scriptargs = str;        // Set global variable sx_scriptargs
        }
    }
    function writeFile(filename,content) {
        io.setSource(filename);
        io.setText(content);
        io.write();
    }
    function readFile(filename) {
        io.setSource(filename);
        if (io.exists()) {
            io.read();
            return io.text;
        } else {
            return "";
        }
    }

    ShellEnv   { id: environment }
    FileIO     { id: io }
    ColumnLayout {
        anchors.fill: parent
        anchors.horizontalCenter: parent.horizontalCenter
        spacing: 5
        Text {
            id: title
            text: "Hosts"
            font.bold: true
            horizontalAlignment: Qt.AlignHCenter
        }
        RowLayout {
            Button {
                text: "Add Host"
                onClicked: {
                    if (newHost.text.trim() !== "") {
                        hostslist.push(newHost.text);
                        writeFile(datafile,JSON.stringify(hostslist));
                        hosts.model = hostslist;
                    }
                }
            }
            Button {
                text: "Delete"
                onClicked: {
                    if (hostgroup.current) {
                        var i=0;
                        while (i<hostslist.length) {
                            if (hostslist[i] === hostgroup.current.text) {
                                hostslist.splice(i,1);
                                break;
                            }
                            i++;
                        }
                        writeFile(datafile,JSON.stringify(hostslist));
                        hosts.model = hostslist;
                        sx_scriptargs = "";
                    }
                }
            }
        }
        TextField {
            id: newHost
            Layout.fillWidth: true
            height: 20
            text: ""
        }
        ExclusiveGroup { id: hostgroup }    // Radio buttons group
        ScrollView {
            Layout.fillWidth: true
            Layout.fillHeight: true
            frameVisible: true
            ListView {
                id: hosts
                spacing: 3
                anchors.fill: parent
                model: hostslist
                delegate: Item {
                    height: 16
                    RadioButton {
                        anchors.margins: 3
                        text: modelData
                        exclusiveGroup: hostgroup
                        checked: false
                        onCheckedChanged: updateParams(index,this);
                    }
                }
            }
        }
    }

    // Set initial parameters when completed
    Component.onCompleted: {
        io.setSource(datafile);
        if (!io.exists())   // First use, create file
            writeFile(datafile,JSON.stringify(hostslist));
        hostslist = JSON.parse(readFile(datafile));
        ready = true;
    }
}
